# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workitems.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import ace_pb2 as ace__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fworkitems.proto\x12\x07openiap\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\tace.proto\"\xaa\x03\n\x08Workitem\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\t\x12\x10\n\x08priority\x18\x04 \x01(\x05\x12+\n\x07nextrun\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07lastrun\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x05\x66iles\x18\x07 \x03(\x0b\x32\x15.openiap.WorkitemFile\x12\r\n\x05state\x18\x08 \x01(\t\x12\x0b\n\x03wiq\x18\t \x01(\t\x12\r\n\x05wiqid\x18\n \x01(\t\x12\x0f\n\x07retries\x18\x0b \x01(\x05\x12\x10\n\x08username\x18\x0c \x01(\t\x12\x15\n\rsuccess_wiqid\x18\r \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\x0e \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x0f \x01(\t\x12\x12\n\nfailed_wiq\x18\x10 \x01(\t\x12\x14\n\x0c\x65rrormessage\x18\x11 \x01(\t\x12\x13\n\x0b\x65rrorsource\x18\x12 \x01(\t\x12\x11\n\terrortype\x18\x13 \x01(\t\"O\n\x0cWorkitemFile\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0b\n\x03_id\x18\x02 \x01(\t\x12\x12\n\ncompressed\x18\x03 \x01(\x08\x12\x0c\n\x04\x66ile\x18\x04 \x01(\x0c\"\x8b\x02\n\x13PushWorkitemRequest\x12\x0b\n\x03wiq\x18\x01 \x01(\t\x12\r\n\x05wiqid\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\t\x12+\n\x07nextrun\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rsuccess_wiqid\x18\x06 \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\x07 \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x08 \x01(\t\x12\x12\n\nfailed_wiq\x18\t \x01(\t\x12\x10\n\x08priority\x18\n \x01(\x05\x12$\n\x05\x66iles\x18\x0b \x03(\x0b\x32\x15.openiap.WorkitemFile\";\n\x14PushWorkitemResponse\x12#\n\x08workitem\x18\x01 \x01(\x0b\x32\x11.openiap.Workitem\"\xe9\x01\n\x14PushWorkitemsRequest\x12\x0b\n\x03wiq\x18\x01 \x01(\t\x12\r\n\x05wiqid\x18\x02 \x01(\t\x12+\n\x07nextrun\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rsuccess_wiqid\x18\x04 \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\x05 \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x06 \x01(\t\x12\x12\n\nfailed_wiq\x18\x07 \x01(\t\x12\x10\n\x08priority\x18\x08 \x01(\x05\x12 \n\x05items\x18\t \x03(\x0b\x32\x11.openiap.Workitem\"=\n\x15PushWorkitemsResponse\x12$\n\tworkitems\x18\x01 \x03(\x0b\x32\x11.openiap.Workitem\"|\n\x15UpdateWorkitemRequest\x12#\n\x08workitem\x18\x01 \x01(\x0b\x32\x11.openiap.Workitem\x12\x18\n\x10ignoremaxretries\x18\x02 \x01(\x08\x12$\n\x05\x66iles\x18\x03 \x03(\x0b\x32\x15.openiap.WorkitemFile\"=\n\x16UpdateWorkitemResponse\x12#\n\x08workitem\x18\x01 \x01(\x0b\x32\x11.openiap.Workitem\"Z\n\x12PopWorkitemRequest\x12\x0b\n\x03wiq\x18\x01 \x01(\t\x12\r\n\x05wiqid\x18\x02 \x01(\t\x12\x14\n\x0cincludefiles\x18\x03 \x01(\x08\x12\x12\n\ncompressed\x18\x04 \x01(\x08\":\n\x13PopWorkitemResponse\x12#\n\x08workitem\x18\x01 \x01(\x0b\x32\x11.openiap.Workitem\"$\n\x15\x44\x65leteWorkitemRequest\x12\x0b\n\x03_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteWorkitemResponse\"\x80\x04\n\rWorkItemQueue\x12\x12\n\nworkflowid\x18\x01 \x01(\t\x12\x12\n\nrobotqueue\x18\x02 \x01(\t\x12\x11\n\tamqpqueue\x18\x03 \x01(\t\x12\x11\n\tprojectid\x18\x04 \x01(\t\x12\x11\n\tusersrole\x18\x05 \x01(\t\x12\x12\n\nmaxretries\x18\x06 \x01(\x05\x12\x12\n\nretrydelay\x18\x07 \x01(\x05\x12\x14\n\x0cinitialdelay\x18\x08 \x01(\x05\x12\x15\n\rsuccess_wiqid\x18\t \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\n \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x0b \x01(\t\x12\x12\n\nfailed_wiq\x18\x0c \x01(\t\x12\x0b\n\x03_id\x18\r \x01(\t\x12\x1a\n\x04_acl\x18\x0e \x03(\x0b\x32\x0c.openiap.Ace\x12\x0c\n\x04name\x18\x0f \x01(\t\x12\x14\n\x0c_createdbyid\x18\x10 \x01(\t\x12\x12\n\n_createdby\x18\x11 \x01(\t\x12,\n\x08_created\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\r_modifiedbyid\x18\x13 \x01(\t\x12\x13\n\x0b_modifiedby\x18\x14 \x01(\t\x12-\n\t_modified\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08_version\x18\x16 \x01(\x05\"\xa3\x02\n\x17\x41\x64\x64WorkItemQueueRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nrobotqueue\x18\x02 \x01(\t\x12\x11\n\tamqpqueue\x18\x03 \x01(\t\x12\x11\n\tprojectid\x18\x04 \x01(\t\x12\x10\n\x08skiprole\x18\x05 \x01(\x08\x12\x12\n\nmaxretries\x18\x06 \x01(\x05\x12\x14\n\x0cinitialdelay\x18\x07 \x01(\x05\x12\x12\n\nretrydelay\x18\x08 \x01(\x05\x12\x15\n\rsuccess_wiqid\x18\t \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\n \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x0b \x01(\t\x12\x12\n\nfailed_wiq\x18\x0c \x01(\t\x12\x1a\n\x04_acl\x18\r \x03(\x0b\x32\x0c.openiap.Ace\"I\n\x18\x41\x64\x64WorkItemQueueResponse\x12-\n\rworkitemqueue\x18\x01 \x01(\x0b\x32\x16.openiap.WorkItemQueueb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workitems_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKITEM._serialized_start=73
  _WORKITEM._serialized_end=499
  _WORKITEMFILE._serialized_start=501
  _WORKITEMFILE._serialized_end=580
  _PUSHWORKITEMREQUEST._serialized_start=583
  _PUSHWORKITEMREQUEST._serialized_end=850
  _PUSHWORKITEMRESPONSE._serialized_start=852
  _PUSHWORKITEMRESPONSE._serialized_end=911
  _PUSHWORKITEMSREQUEST._serialized_start=914
  _PUSHWORKITEMSREQUEST._serialized_end=1147
  _PUSHWORKITEMSRESPONSE._serialized_start=1149
  _PUSHWORKITEMSRESPONSE._serialized_end=1210
  _UPDATEWORKITEMREQUEST._serialized_start=1212
  _UPDATEWORKITEMREQUEST._serialized_end=1336
  _UPDATEWORKITEMRESPONSE._serialized_start=1338
  _UPDATEWORKITEMRESPONSE._serialized_end=1399
  _POPWORKITEMREQUEST._serialized_start=1401
  _POPWORKITEMREQUEST._serialized_end=1491
  _POPWORKITEMRESPONSE._serialized_start=1493
  _POPWORKITEMRESPONSE._serialized_end=1551
  _DELETEWORKITEMREQUEST._serialized_start=1553
  _DELETEWORKITEMREQUEST._serialized_end=1589
  _DELETEWORKITEMRESPONSE._serialized_start=1591
  _DELETEWORKITEMRESPONSE._serialized_end=1615
  _WORKITEMQUEUE._serialized_start=1618
  _WORKITEMQUEUE._serialized_end=2130
  _ADDWORKITEMQUEUEREQUEST._serialized_start=2133
  _ADDWORKITEMQUEUEREQUEST._serialized_end=2424
  _ADDWORKITEMQUEUERESPONSE._serialized_start=2426
  _ADDWORKITEMQUEUERESPONSE._serialized_end=2499
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from . import querys_pb2 as querys__pb2
from . import queues_pb2 as queues__pb2
from . import watch_pb2 as watch__pb2
from . import workitems_pb2 as workitems__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nbase.proto\x12\x07openiap\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x0cquerys.proto\x1a\x0cqueues.proto\x1a\x0bwatch.proto\x1a\x0fworkitems.proto\"\xa5\x01\n\x08\x45nvelope\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x10\n\x08priority\x18\x02 \x01(\x05\x12\x0b\n\x03seq\x18\x03 \x01(\x05\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0b\n\x03rid\x18\x05 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0b\n\x03jwt\x18\x07 \x01(\t\x12\x0f\n\x07traceid\x18\x08 \x01(\t\x12\x0e\n\x06spanid\x18\t \x01(\t\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"=\n\rErrorResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\r\n\x05stack\x18\x03 \x01(\t\"\"\n\x11GetElementRequest\x12\r\n\x05xpath\x18\x01 \x01(\t\"#\n\x12GetElementResponse\x12\r\n\x05xpath\x18\x01 \x01(\t\"/\n\x0f\x44ownloadRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\"B\n\x10\x44ownloadResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x10\n\x08mimetype\x18\x03 \x01(\t\"3\n\rUploadRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x10\n\x08mimetype\x18\x02 \x01(\t\"|\n\x0eUploadResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\r\n\x05\x62ytes\x18\x03 \x01(\x05\x12\x0e\n\x06\x63hunks\x18\x04 \x01(\x05\x12\n\n\x02mb\x18\x05 \x01(\x02\x12\x13\n\x0b\x65lapsedTime\x18\x06 \x01(\x05\x12\x0c\n\x04mbps\x18\x07 \x01(\x02\"<\n\x0b\x42\x65ginStream\x12\x10\n\x08\x63hecksum\x18\x01 \x01(\t\x12\x1b\n\x04stat\x18\x02 \x01(\x0b\x32\r.openiap.Stat\"\x16\n\x06Stream\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x0b\n\tEndStream\"\xa1\x02\n\x04Stat\x12\x13\n\x0b\x62irthtimeMs\x18\x01 \x01(\x02\x12\x0f\n\x07\x62lksize\x18\x02 \x01(\x05\x12\x0e\n\x06\x62locks\x18\x03 \x01(\x05\x12)\n\x05\x63time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63timeMs\x18\x05 \x01(\x02\x12\x0b\n\x03\x64\x65v\x18\x06 \x01(\x05\x12\x0b\n\x03gid\x18\x07 \x01(\x05\x12\x0b\n\x03ino\x18\x08 \x01(\x05\x12\x0c\n\x04mode\x18\t \x01(\x05\x12)\n\x05mtime\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07mtimeMs\x18\x0b \x01(\x02\x12\r\n\x05nlink\x18\x0c \x01(\x05\x12\x0c\n\x04rdev\x18\r \x01(\x05\x12\x0c\n\x04size\x18\x0e \x01(\x05\x12\x0b\n\x03uid\x18\x0f \x01(\x05\"O\n\x14\x43ustomCommandRequest\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\t\"\'\n\x15\x43ustomCommandResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x84\x01\n\rSigninRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0b\n\x03jwt\x18\x03 \x01(\t\x12\x0c\n\x04ping\x18\x04 \x01(\x08\x12\x14\n\x0cvalidateonly\x18\x05 \x01(\x08\x12\r\n\x05\x61gent\x18\x06 \x01(\t\x12\x0f\n\x07version\x18\x07 \x01(\t\":\n\x0eSigninResponse\x12\x0b\n\x03jwt\x18\x01 \x01(\t\x12\x1b\n\x04user\x18\x02 \x01(\x0b\x32\r.openiap.User\"J\n\x0cRefreshToken\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0b\n\x03jwt\x18\x02 \x01(\t\x12\x1b\n\x04user\x18\x03 \x01(\x0b\x32\r.openiap.User\"!\n\x04Role\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"`\n\x04User\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x1c\n\x05roles\x18\x05 \x03(\x0b\x32\r.openiap.Role2\x9b\x12\n\x0b\x46lowService\x12\x39\n\x0bSetupStream\x12\x11.openiap.Envelope\x1a\x11.openiap.Envelope\"\x00(\x01\x30\x01\x12\x39\n\x06Signin\x12\x16.openiap.SigninRequest\x1a\x17.openiap.SigninResponse\x12?\n\x08\x44ownload\x12\x18.openiap.DownloadRequest\x1a\x19.openiap.DownloadResponse\x12\x39\n\x06Upload\x12\x16.openiap.UploadRequest\x1a\x17.openiap.UploadResponse\x12N\n\rCustomCommand\x12\x1d.openiap.CustomCommandRequest\x1a\x1e.openiap.CustomCommandResponse\x12T\n\x0fListCollections\x12\x1f.openiap.ListCollectionsRequest\x1a .openiap.ListCollectionsResponse\x12Q\n\x0e\x44ropCollection\x12\x1e.openiap.DropCollectionRequest\x1a\x1f.openiap.DropCollectionResponse\x12\x36\n\x05Query\x12\x15.openiap.QueryRequest\x1a\x16.openiap.QueryResponse\x12]\n\x12GetDocumentVersion\x12\".openiap.GetDocumentVersionRequest\x1a#.openiap.GetDocumentVersionResponse\x12\x42\n\tAggregate\x12\x19.openiap.AggregateRequest\x1a\x1a.openiap.AggregateResponse\x12\x36\n\x05\x43ount\x12\x15.openiap.CountRequest\x1a\x16.openiap.CountResponse\x12\x42\n\tInsertOne\x12\x19.openiap.InsertOneRequest\x1a\x1a.openiap.InsertOneResponse\x12\x45\n\nInsertMany\x12\x1a.openiap.InsertManyRequest\x1a\x1b.openiap.InsertManyResponse\x12\x42\n\tUpdateOne\x12\x19.openiap.UpdateOneRequest\x1a\x1a.openiap.UpdateOneResponse\x12Q\n\x0eUpdateDocument\x12\x1e.openiap.UpdateDocumentRequest\x1a\x1f.openiap.UpdateDocumentResponse\x12Z\n\x11InsertOrUpdateOne\x12!.openiap.InsertOrUpdateOneRequest\x1a\".openiap.InsertOrUpdateOneResponse\x12]\n\x12InsertOrUpdateMany\x12\".openiap.InsertOrUpdateManyRequest\x1a#.openiap.InsertOrUpdateManyResponse\x12\x42\n\tDeleteOne\x12\x19.openiap.DeleteOneRequest\x1a\x1a.openiap.DeleteOneResponse\x12\x45\n\nDeleteMany\x12\x1a.openiap.DeleteManyRequest\x1a\x1b.openiap.DeleteManyResponse\x12N\n\rRegisterQueue\x12\x1d.openiap.RegisterQueueRequest\x1a\x1e.openiap.RegisterQueueResponse\x12W\n\x10RegisterExchange\x12 .openiap.RegisterExchangeRequest\x1a!.openiap.RegisterExchangeResponse\x12K\n\x0cQueueMessage\x12\x1c.openiap.QueueMessageRequest\x1a\x1d.openiap.QueueMessageResponse\x12T\n\x0fUnRegisterQueue\x12\x1f.openiap.UnRegisterQueueRequest\x1a .openiap.UnRegisterQueueResponse\x12\x36\n\x05Watch\x12\x15.openiap.WatchRequest\x1a\x16.openiap.WatchResponse\x12<\n\x07UnWatch\x12\x17.openiap.UnWatchRequest\x1a\x18.openiap.UnWatchResponse\x12K\n\x0cPushWorkitem\x12\x1c.openiap.PushWorkitemRequest\x1a\x1d.openiap.PushWorkitemResponse\x12N\n\rPushWorkitems\x12\x1d.openiap.PushWorkitemsRequest\x1a\x1e.openiap.PushWorkitemsResponse\x12Q\n\x0eUpdateWorkitem\x12\x1e.openiap.UpdateWorkitemRequest\x1a\x1f.openiap.UpdateWorkitemResponse\x12H\n\x0bPopWorkitem\x12\x1b.openiap.PopWorkitemRequest\x1a\x1c.openiap.PopWorkitemResponse\x12Q\n\x0e\x44\x65leteWorkitem\x12\x1e.openiap.DeleteWorkitemRequest\x1a\x1f.openiap.DeleteWorkitemResponse\x12W\n\x10\x41\x64\x64WorkItemQueue\x12 .openiap.AddWorkItemQueueRequest\x1a!.openiap.AddWorkItemQueueResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'base_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENVELOPE._serialized_start=142
  _ENVELOPE._serialized_end=307
  _PINGREQUEST._serialized_start=309
  _PINGREQUEST._serialized_end=322
  _PINGRESPONSE._serialized_start=324
  _PINGRESPONSE._serialized_end=338
  _ERRORRESPONSE._serialized_start=340
  _ERRORRESPONSE._serialized_end=401
  _GETELEMENTREQUEST._serialized_start=403
  _GETELEMENTREQUEST._serialized_end=437
  _GETELEMENTRESPONSE._serialized_start=439
  _GETELEMENTRESPONSE._serialized_end=474
  _DOWNLOADREQUEST._serialized_start=476
  _DOWNLOADREQUEST._serialized_end=523
  _DOWNLOADRESPONSE._serialized_start=525
  _DOWNLOADRESPONSE._serialized_end=591
  _UPLOADREQUEST._serialized_start=593
  _UPLOADREQUEST._serialized_end=644
  _UPLOADRESPONSE._serialized_start=646
  _UPLOADRESPONSE._serialized_end=770
  _BEGINSTREAM._serialized_start=772
  _BEGINSTREAM._serialized_end=832
  _STREAM._serialized_start=834
  _STREAM._serialized_end=856
  _ENDSTREAM._serialized_start=858
  _ENDSTREAM._serialized_end=869
  _STAT._serialized_start=872
  _STAT._serialized_end=1161
  _CUSTOMCOMMANDREQUEST._serialized_start=1163
  _CUSTOMCOMMANDREQUEST._serialized_end=1242
  _CUSTOMCOMMANDRESPONSE._serialized_start=1244
  _CUSTOMCOMMANDRESPONSE._serialized_end=1283
  _SIGNINREQUEST._serialized_start=1286
  _SIGNINREQUEST._serialized_end=1418
  _SIGNINRESPONSE._serialized_start=1420
  _SIGNINRESPONSE._serialized_end=1478
  _REFRESHTOKEN._serialized_start=1480
  _REFRESHTOKEN._serialized_end=1554
  _ROLE._serialized_start=1556
  _ROLE._serialized_end=1589
  _USER._serialized_start=1591
  _USER._serialized_end=1687
  _FLOWSERVICE._serialized_start=1690
  _FLOWSERVICE._serialized_end=4021
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: queues.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cqueues.proto\x12\x07openiap\")\n\x14RegisterQueueRequest\x12\x11\n\tqueuename\x18\x01 \x01(\t\"*\n\x15RegisterQueueResponse\x12\x11\n\tqueuename\x18\x01 \x01(\t\"h\n\x17RegisterExchangeRequest\x12\x14\n\x0c\x65xchangename\x18\x01 \x01(\t\x12\x11\n\talgorithm\x18\x02 \x01(\t\x12\x12\n\nroutingkey\x18\x03 \x01(\t\x12\x10\n\x08\x61\x64\x64queue\x18\x04 \x01(\x08\"-\n\x18RegisterExchangeResponse\x12\x11\n\tqueuename\x18\x01 \x01(\t\"\x9c\x01\n\x13QueueMessageRequest\x12\x11\n\tqueuename\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\t\x12\x0f\n\x07replyto\x18\x03 \x01(\t\x12\x12\n\nroutingkey\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangename\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\x12\x12\n\nstriptoken\x18\x07 \x01(\x08\"\x89\x01\n\x14QueueMessageResponse\x12\x11\n\tqueuename\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\t\x12\x0f\n\x07replyto\x18\x03 \x01(\t\x12\x12\n\nroutingkey\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangename\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"\x7f\n\nQueueEvent\x12\x11\n\tqueuename\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\t\x12\x0f\n\x07replyto\x18\x03 \x01(\t\x12\x12\n\nroutingkey\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangename\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"+\n\x16UnRegisterQueueRequest\x12\x11\n\tqueuename\x18\x01 \x01(\t\"\x19\n\x17UnRegisterQueueResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'queues_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGISTERQUEUEREQUEST._serialized_start=25
  _REGISTERQUEUEREQUEST._serialized_end=66
  _REGISTERQUEUERESPONSE._serialized_start=68
  _REGISTERQUEUERESPONSE._serialized_end=110
  _REGISTEREXCHANGEREQUEST._serialized_start=112
  _REGISTEREXCHANGEREQUEST._serialized_end=216
  _REGISTEREXCHANGERESPONSE._serialized_start=218
  _REGISTEREXCHANGERESPONSE._serialized_end=263
  _QUEUEMESSAGEREQUEST._serialized_start=266
  _QUEUEMESSAGEREQUEST._serialized_end=422
  _QUEUEMESSAGERESPONSE._serialized_start=425
  _QUEUEMESSAGERESPONSE._serialized_end=562
  _QUEUEEVENT._serialized_start=564
  _QUEUEEVENT._serialized_end=691
  _UNREGISTERQUEUEREQUEST._serialized_start=693
  _UNREGISTERQUEUEREQUEST._serialized_end=736
  _UNREGISTERQUEUERESPONSE._serialized_start=738
  _UNREGISTERQUEUERESPONSE._serialized_end=763
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: querys.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cquerys.proto\x12\x07openiap\"-\n\x16ListCollectionsRequest\x12\x13\n\x0bincludehist\x18\x01 \x01(\x08\"*\n\x17ListCollectionsResponse\x12\x0f\n\x07results\x18\x01 \x01(\t\"/\n\x15\x44ropCollectionRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\"\x18\n\x16\x44ropCollectionResponse\"\x86\x01\n\x0cQueryRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x16\n\x0e\x63ollectionname\x18\x02 \x01(\t\x12\x12\n\nprojection\x18\x03 \x01(\t\x12\x0b\n\x03top\x18\x04 \x01(\x05\x12\x0c\n\x04skip\x18\x05 \x01(\x05\x12\x0f\n\x07orderby\x18\x06 \x01(\t\x12\x0f\n\x07queryas\x18\x07 \x01(\t\" \n\rQueryResponse\x12\x0f\n\x07results\x18\x01 \x01(\t\"a\n\x19GetDocumentVersionRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x0f\n\x07\x64\x65\x63rypt\x18\x04 \x01(\x08\",\n\x1aGetDocumentVersionResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"]\n\x10\x41ggregateRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x12\n\naggregates\x18\x02 \x01(\t\x12\x0f\n\x07queryas\x18\x03 \x01(\t\x12\x0c\n\x04hint\x18\x04 \x01(\t\"$\n\x11\x41ggregateResponse\x12\x0f\n\x07results\x18\x01 \x01(\t\"F\n\x0c\x43ountRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x0f\n\x07queryas\x18\x03 \x01(\t\"\x1f\n\rCountResponse\x12\x0e\n\x06result\x18\x01 \x01(\x05\"N\n\x10InsertOneRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x0c\n\x04item\x18\x02 \x01(\t\x12\t\n\x01w\x18\x03 \x01(\x05\x12\t\n\x01j\x18\x04 \x01(\x08\"#\n\x11InsertOneResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"e\n\x11InsertManyRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05items\x18\x02 \x01(\t\x12\t\n\x01w\x18\x03 \x01(\x05\x12\t\n\x01j\x18\x04 \x01(\x08\x12\x13\n\x0bskipresults\x18\x05 \x01(\x08\"%\n\x12InsertManyResponse\x12\x0f\n\x07results\x18\x01 \x01(\t\"N\n\x10UpdateOneRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x0c\n\x04item\x18\x02 \x01(\t\x12\t\n\x01w\x18\x03 \x01(\x05\x12\t\n\x01j\x18\x04 \x01(\x08\"#\n\x11UpdateOneResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"f\n\x15UpdateDocumentRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x10\n\x08\x64ocument\x18\x03 \x01(\t\x12\t\n\x01w\x18\x04 \x01(\x05\x12\t\n\x01j\x18\x05 \x01(\x08\"|\n\x0cUpdateResult\x12\x14\n\x0c\x61\x63knowledged\x18\x01 \x01(\x08\x12\x14\n\x0cmatchedCount\x18\x02 \x01(\x05\x12\x15\n\rmodifiedCount\x18\x03 \x01(\x05\x12\x15\n\rupsertedCount\x18\x04 \x01(\x05\x12\x12\n\nupsertedId\x18\x05 \x01(\t\"A\n\x16UpdateDocumentResponse\x12\'\n\x08opresult\x18\x01 \x01(\x0b\x32\x15.openiap.UpdateResult\"i\n\x18InsertOrUpdateOneRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x11\n\tuniqeness\x18\x02 \x01(\t\x12\x0c\n\x04item\x18\x03 \x01(\t\x12\t\n\x01w\x18\x04 \x01(\x05\x12\t\n\x01j\x18\x05 \x01(\x08\"+\n\x19InsertOrUpdateOneResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x80\x01\n\x19InsertOrUpdateManyRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x11\n\tuniqeness\x18\x02 \x01(\t\x12\r\n\x05items\x18\x03 \x01(\t\x12\t\n\x01w\x18\x04 \x01(\x05\x12\t\n\x01j\x18\x05 \x01(\x08\x12\x13\n\x0bskipresults\x18\x06 \x01(\x08\"-\n\x1aInsertOrUpdateManyResponse\x12\x0f\n\x07results\x18\x01 \x01(\t\"I\n\x10\x44\x65leteOneRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\trecursive\x18\x03 \x01(\x08\")\n\x11\x44\x65leteOneResponse\x12\x14\n\x0c\x61\x66\x66\x65\x63tedrows\x18\x01 \x01(\x05\"Z\n\x11\x44\x65leteManyRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x11\n\trecursive\x18\x03 \x01(\x08\x12\x0b\n\x03ids\x18\x04 \x03(\t\"*\n\x12\x44\x65leteManyResponse\x12\x14\n\x0c\x61\x66\x66\x65\x63tedrows\x18\x01 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'querys_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LISTCOLLECTIONSREQUEST._serialized_start=25
  _LISTCOLLECTIONSREQUEST._serialized_end=70
  _LISTCOLLECTIONSRESPONSE._serialized_start=72
  _LISTCOLLECTIONSRESPONSE._serialized_end=114
  _DROPCOLLECTIONREQUEST._serialized_start=116
  _DROPCOLLECTIONREQUEST._serialized_end=163
  _DROPCOLLECTIONRESPONSE._serialized_start=165
  _DROPCOLLECTIONRESPONSE._serialized_end=189
  _QUERYREQUEST._serialized_start=192
  _QUERYREQUEST._serialized_end=326
  _QUERYRESPONSE._serialized_start=328
  _QUERYRESPONSE._serialized_end=360
  _GETDOCUMENTVERSIONREQUEST._serialized_start=362
  _GETDOCUMENTVERSIONREQUEST._serialized_end=459
  _GETDOCUMENTVERSIONRESPONSE._serialized_start=461
  _GETDOCUMENTVERSIONRESPONSE._serialized_end=505
  _AGGREGATEREQUEST._serialized_start=507
  _AGGREGATEREQUEST._serialized_end=600
  _AGGREGATERESPONSE._serialized_start=602
  _AGGREGATERESPONSE._serialized_end=638
  _COUNTREQUEST._serialized_start=640
  _COUNTREQUEST._serialized_end=710
  _COUNTRESPONSE._serialized_start=712
  _COUNTRESPONSE._serialized_end=743
  _INSERTONEREQUEST._serialized_start=745
  _INSERTONEREQUEST._serialized_end=823
  _INSERTONERESPONSE._serialized_start=825
  _INSERTONERESPONSE._serialized_end=860
  _INSERTMANYREQUEST._serialized_start=862
  _INSERTMANYREQUEST._serialized_end=963
  _INSERTMANYRESPONSE._serialized_start=965
  _INSERTMANYRESPONSE._serialized_end=1002
  _UPDATEONEREQUEST._serialized_start=1004
  _UPDATEONEREQUEST._serialized_end=1082
  _UPDATEONERESPONSE._serialized_start=1084
  _UPDATEONERESPONSE._serialized_end=1119
  _UPDATEDOCUMENTREQUEST._serialized_start=1121
  _UPDATEDOCUMENTREQUEST._serialized_end=1223
  _UPDATERESULT._serialized_start=1225
  _UPDATERESULT._serialized_end=1349
  _UPDATEDOCUMENTRESPONSE._serialized_start=1351
  _UPDATEDOCUMENTRESPONSE._serialized_end=1416
  _INSERTORUPDATEONEREQUEST._serialized_start=1418
  _INSERTORUPDATEONEREQUEST._serialized_end=1523
  _INSERTORUPDATEONERESPONSE._serialized_start=1525
  _INSERTORUPDATEONERESPONSE._serialized_end=1568
  _INSERTORUPDATEMANYREQUEST._serialized_start=1571
  _INSERTORUPDATEMANYREQUEST._serialized_end=1699
  _INSERTORUPDATEMANYRESPONSE._serialized_start=1701
  _INSERTORUPDATEMANYRESPONSE._serialized_end=1746
  _DELETEONEREQUEST._serialized_start=1748
  _DELETEONEREQUEST._serialized_end=1821
  _DELETEONERESPONSE._serialized_start=1823
  _DELETEONERESPONSE._serialized_end=1864
  _DELETEMANYREQUEST._serialized_start=1866
  _DELETEMANYREQUEST._serialized_end=1956
  _DELETEMANYRESPONSE._serialized_start=1958
  _DELETEMANYRESPONSE._serialized_end=2000
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import base_pb2 as base__pb2
from . import querys_pb2 as querys__pb2
from . import queues_pb2 as queues__pb2
from . import watch_pb2 as watch__pb2
from . import workitems_pb2 as workitems__pb2


class FlowServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetupStream = channel.stream_stream(
                '/openiap.FlowService/SetupStream',
                request_serializer=base__pb2.Envelope.SerializeToString,
                response_deserializer=base__pb2.Envelope.FromString,
                )
        self.Signin = channel.unary_unary(
                '/openiap.FlowService/Signin',
                request_serializer=base__pb2.SigninRequest.SerializeToString,
                response_deserializer=base__pb2.SigninResponse.FromString,
                )
        self.Download = channel.unary_unary(
                '/openiap.FlowService/Download',
                request_serializer=base__pb2.DownloadRequest.SerializeToString,
                response_deserializer=base__pb2.DownloadResponse.FromString,
                )
        self.Upload = channel.unary_unary(
                '/openiap.FlowService/Upload',
                request_serializer=base__pb2.UploadRequest.SerializeToString,
                response_deserializer=base__pb2.UploadResponse.FromString,
                )
        self.CustomCommand = channel.unary_unary(
                '/openiap.FlowService/CustomCommand',
                request_serializer=base__pb2.CustomCommandRequest.SerializeToString,
                response_deserializer=base__pb2.CustomCommandResponse.FromString,
                )
        self.ListCollections = channel.unary_unary(
                '/openiap.FlowService/ListCollections',
                request_serializer=querys__pb2.ListCollectionsRequest.SerializeToString,
                response_deserializer=querys__pb2.ListCollectionsResponse.FromString,
                )
        self.DropCollection = channel.unary_unary(
                '/openiap.FlowService/DropCollection',
                request_serializer=querys__pb2.DropCollectionRequest.SerializeToString,
                response_deserializer=querys__pb2.DropCollectionResponse.FromString,
                )
        self.Query = channel.unary_unary(
                '/openiap.FlowService/Query',
                request_serializer=querys__pb2.QueryRequest.SerializeToString,
                response_deserializer=querys__pb2.QueryResponse.FromString,
                )
        self.GetDocumentVersion = channel.unary_unary(
                '/openiap.FlowService/GetDocumentVersion',
                request_serializer=querys__pb2.GetDocumentVersionRequest.SerializeToString,
                response_deserializer=querys__pb2.GetDocumentVersionResponse.FromString,
                )
        self.Aggregate = channel.unary_unary(
                '/openiap.FlowService/Aggregate',
                request_serializer=querys__pb2.AggregateRequest.SerializeToString,
                response_deserializer=querys__pb2.AggregateResponse.FromString,
                )
        self.Count = channel.unary_unary(
                '/openiap.FlowService/Count',
                request_serializer=querys__pb2.CountRequest.SerializeToString,
                response_deserializer=querys__pb2.CountResponse.FromString,
                )
        self.InsertOne = channel.unary_unary(
                '/openiap.FlowService/InsertOne',
                request_serializer=querys__pb2.InsertOneRequest.SerializeToString,
                response_deserializer=querys__pb2.InsertOneResponse.FromString,
                )
        self.InsertMany = channel.unary_unary(
                '/openiap.FlowService/InsertMany',
                request_serializer=querys__pb2.InsertManyRequest.SerializeToString,
                response_deserializer=querys__pb2.InsertManyResponse.FromString,
                )
        self.UpdateOne = channel.unary_unary(
                '/openiap.FlowService/UpdateOne',
                request_serializer=querys__pb2.UpdateOneRequest.SerializeToString,
                response_deserializer=querys__pb2.UpdateOneResponse.FromString,
                )
        self.UpdateDocument = channel.unary_unary(
                '/openiap.FlowService/UpdateDocument',
                request_serializer=querys__pb2.UpdateDocumentRequest.SerializeToString,
                response_deserializer=querys__pb2.UpdateDocumentResponse.FromString,
                )
        self.InsertOrUpdateOne = channel.unary_unary(
                '/openiap.FlowService/InsertOrUpdateOne',
                request_serializer=querys__pb2.InsertOrUpdateOneRequest.SerializeToString,
                response_deserializer=querys__pb2.InsertOrUpdateOneResponse.FromString,
                )
        self.InsertOrUpdateMany = channel.unary_unary(
                '/openiap.FlowService/InsertOrUpdateMany',
                request_serializer=querys__pb2.InsertOrUpdateManyRequest.SerializeToString,
                response_deserializer=querys__pb2.InsertOrUpdateManyResponse.FromString,
                )
        self.DeleteOne = channel.unary_unary(
                '/openiap.FlowService/DeleteOne',
                request_serializer=querys__pb2.DeleteOneRequest.SerializeToString,
                response_deserializer=querys__pb2.DeleteOneResponse.FromString,
                )
        self.DeleteMany = channel.unary_unary(
                '/openiap.FlowService/DeleteMany',
                request_serializer=querys__pb2.DeleteManyRequest.SerializeToString,
                response_deserializer=querys__pb2.DeleteManyResponse.FromString,
                )
        self.RegisterQueue = channel.unary_unary(
                '/openiap.FlowService/RegisterQueue',
                request_serializer=queues__pb2.RegisterQueueRequest.SerializeToString,
                response_deserializer=queues__pb2.RegisterQueueResponse.FromString,
                )
        self.RegisterExchange = channel.unary_unary(
                '/openiap.FlowService/RegisterExchange',
                request_serializer=queues__pb2.RegisterExchangeRequest.SerializeToString,
                response_deserializer=queues__pb2.RegisterExchangeResponse.FromString,
                )
        self.QueueMessage = channel.unary_unary(
                '/openiap.FlowService/QueueMessage',
                request_serializer=queues__pb2.QueueMessageRequest.SerializeToString,
                response_deserializer=queues__pb2.QueueMessageResponse.FromString,
                )
        self.UnRegisterQueue = channel.unary_unary(
                '/openiap.FlowService/UnRegisterQueue',
                request_serializer=queues__pb2.UnRegisterQueueRequest.SerializeToString,
                response_deserializer=queues__pb2.UnRegisterQueueResponse.FromString,
                )
        self.Watch = channel.unary_unary(
                '/openiap.FlowService/Watch',
                request_serializer=watch__pb2.WatchRequest.SerializeToString,
                response_deserializer=watch__pb2.WatchResponse.FromString,
                )
        self.UnWatch = channel.unary_unary(
                '/openiap.FlowService/UnWatch',
                request_serializer=watch__pb2.UnWatchRequest.SerializeToString,
                response_deserializer=watch__pb2.UnWatchResponse.FromString,
                )
        self.PushWorkitem = channel.unary_unary(
                '/openiap.FlowService/PushWorkitem',
                request_serializer=workitems__pb2.PushWorkitemRequest.SerializeToString,
                response_deserializer=workitems__pb2.PushWorkitemResponse.FromString,
                )
        self.PushWorkitems = channel.unary_unary(
                '/openiap.FlowService/PushWorkitems',
                request_serializer=workitems__pb2.PushWorkitemsRequest.SerializeToString,
                response_deserializer=workitems__pb2.PushWorkitemsResponse.FromString,
                )
        self.UpdateWorkitem = channel.unary_unary(
                '/openiap.FlowService/UpdateWorkitem',
                request_serializer=workitems__pb2.UpdateWorkitemRequest.SerializeToString,
                response_deserializer=workitems__pb2.UpdateWorkitemResponse.FromString,
                )
        self.PopWorkitem = channel.unary_unary(
                '/openiap.FlowService/PopWorkitem',
                request_serializer=workitems__pb2.PopWorkitemRequest.SerializeToString,
                response_deserializer=workitems__pb2.PopWorkitemResponse.FromString,
                )
        self.DeleteWorkitem = channel.unary_unary(
                '/openiap.FlowService/DeleteWorkitem',
                request_serializer=workitems__pb2.DeleteWorkitemRequest.SerializeToString,
                response_deserializer=workitems__pb2.DeleteWorkitemResponse.FromString,
                )
        self.AddWorkItemQueue = channel.unary_unary(
                '/openiap.FlowService/AddWorkItemQueue',
                request_serializer=workitems__pb2.AddWorkItemQueueRequest.SerializeToString,
                response_deserializer=workitems__pb2.AddWorkItemQueueResponse.FromString,
                )


class FlowServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SetupStream(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Signin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Download(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Upload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CustomCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCollections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DropCollection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Query(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDocumentVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Aggregate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Count(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsertOne(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsertMany(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOne(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDocument(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsertOrUpdateOne(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsertOrUpdateMany(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOne(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMany(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterQueue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterExchange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueueMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnRegisterQueue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Watch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnWatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PushWorkitem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PushWorkitems(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWorkitem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PopWorkitem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteWorkitem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddWorkItemQueue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FlowServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetupStream': grpc.stream_stream_rpc_method_handler(
                    servicer.SetupStream,
                    request_deserializer=base__pb2.Envelope.FromString,
                    response_serializer=base__pb2.Envelope.SerializeToString,
            ),
            'Signin': grpc.unary_unary_rpc_method_handler(
                    servicer.Signin,
                    request_deserializer=base__pb2.SigninRequest.FromString,
                    response_serializer=base__pb2.SigninResponse.SerializeToString,
            ),
            'Download': grpc.unary_unary_rpc_method_handler(
                    servicer.Download,
                    request_deserializer=base__pb2.DownloadRequest.FromString,
                    response_serializer=base__pb2.DownloadResponse.SerializeToString,
            ),
            'Upload': grpc.unary_unary_rpc_method_handler(
                    servicer.Upload,
                    request_deserializer=base__pb2.UploadRequest.FromString,
                    response_serializer=base__pb2.UploadResponse.SerializeToString,
            ),
            'CustomCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.CustomCommand,
                    request_deserializer=base__pb2.CustomCommandRequest.FromString,
                    response_serializer=base__pb2.CustomCommandResponse.SerializeToString,
            ),
            'ListCollections': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCollections,
                    request_deserializer=querys__pb2.ListCollectionsRequest.FromString,
                    response_serializer=querys__pb2.ListCollectionsResponse.SerializeToString,
            ),
            'DropCollection': grpc.unary_unary_rpc_method_handler(
                    servicer.DropCollection,
                    request_deserializer=querys__pb2.DropCollectionRequest.FromString,
                    response_serializer=querys__pb2.DropCollectionResponse.SerializeToString,
            ),
            'Query': grpc.unary_unary_rpc_method_handler(
                    servicer.Query,
                    request_deserializer=querys__pb2.QueryRequest.FromString,
                    response_serializer=querys__pb2.QueryResponse.SerializeToString,
            ),
            'GetDocumentVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDocumentVersion,
                    request_deserializer=querys__pb2.GetDocumentVersionRequest.FromString,
                    response_serializer=querys__pb2.GetDocumentVersionResponse.SerializeToString,
            ),
            'Aggregate': grpc.unary_unary_rpc_method_handler(
                    servicer.Aggregate,
                    request_deserializer=querys__pb2.AggregateRequest.FromString,
                    response_serializer=querys__pb2.AggregateResponse.SerializeToString,
            ),
            'Count': grpc.unary_unary_rpc_method_handler(
                    servicer.Count,
                    request_deserializer=querys__pb2.CountRequest.FromString,
                    response_serializer=querys__pb2.CountResponse.SerializeToString,
            ),
            'InsertOne': grpc.unary_unary_rpc_method_handler(
                    servicer.InsertOne,
                    request_deserializer=querys__pb2.InsertOneRequest.FromString,
                    response_serializer=querys__pb2.InsertOneResponse.SerializeToString,
            ),
            'InsertMany': grpc.unary_unary_rpc_method_handler(
                    servicer.InsertMany,
                    request_deserializer=querys__pb2.InsertManyRequest.FromString,
                    response_serializer=querys__pb2.InsertManyResponse.SerializeToString,
            ),
            'UpdateOne': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOne,
                    request_deserializer=querys__pb2.UpdateOneRequest.FromString,
                    response_serializer=querys__pb2.UpdateOneResponse.SerializeToString,
            ),
            'UpdateDocument': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDocument,
                    request_deserializer=querys__pb2.UpdateDocumentRequest.FromString,
                    response_serializer=querys__pb2.UpdateDocumentResponse.SerializeToString,
            ),
            'InsertOrUpdateOne': grpc.unary_unary_rpc_method_handler(
                    servicer.InsertOrUpdateOne,
                    request_deserializer=querys__pb2.InsertOrUpdateOneRequest.FromString,
                    response_serializer=querys__pb2.InsertOrUpdateOneResponse.SerializeToString,
            ),
            'InsertOrUpdateMany': grpc.unary_unary_rpc_method_handler(
                    servicer.InsertOrUpdateMany,
                    request_deserializer=querys__pb2.InsertOrUpdateManyRequest.FromString,
                    response_serializer=querys__pb2.InsertOrUpdateManyResponse.SerializeToString,
            ),
            'DeleteOne': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOne,
                    request_deserializer=querys__pb2.DeleteOneRequest.FromString,
                    response_serializer=querys__pb2.DeleteOneResponse.SerializeToString,
            ),
            'DeleteMany': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMany,
                    request_deserializer=querys__pb2.DeleteManyRequest.FromString,
                    response_serializer=querys__pb2.DeleteManyResponse.SerializeToString,
            ),
            'RegisterQueue': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterQueue,
                    request_deserializer=queues__pb2.RegisterQueueRequest.FromString,
                    response_serializer=queues__pb2.RegisterQueueResponse.SerializeToString,
            ),
            'RegisterExchange': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterExchange,
                    request_deserializer=queues__pb2.RegisterExchangeRequest.FromString,
                    response_serializer=queues__pb2.RegisterExchangeResponse.SerializeToString,
            ),
            'QueueMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.QueueMessage,
                    request_deserializer=queues__pb2.QueueMessageRequest.FromString,
                    response_serializer=queues__pb2.QueueMessageResponse.SerializeToString,
            ),
            'UnRegisterQueue': grpc.unary_unary_rpc_method_handler(
                    servicer.UnRegisterQueue,
                    request_deserializer=queues__pb2.UnRegisterQueueRequest.FromString,
                    response_serializer=queues__pb2.UnRegisterQueueResponse.SerializeToString,
            ),
            'Watch': grpc.unary_unary_rpc_method_handler(
                    servicer.Watch,
                    request_deserializer=watch__pb2.WatchRequest.FromString,
                    response_serializer=watch__pb2.WatchResponse.SerializeToString,
            ),
            'UnWatch': grpc.unary_unary_rpc_method_handler(
                    servicer.UnWatch,
                    request_deserializer=watch__pb2.UnWatchRequest.FromString,
                    response_serializer=watch__pb2.UnWatchResponse.SerializeToString,
            ),
            'PushWorkitem': grpc.unary_unary_rpc_method_handler(
                    servicer.PushWorkitem,
                    request_deserializer=workitems__pb2.PushWorkitemRequest.FromString,
                    response_serializer=workitems__pb2.PushWorkitemResponse.SerializeToString,
            ),
            'PushWorkitems': grpc.unary_unary_rpc_method_handler(
                    servicer.PushWorkitems,
                    request_deserializer=workitems__pb2.PushWorkitemsRequest.FromString,
                    response_serializer=workitems__pb2.PushWorkitemsResponse.SerializeToString,
            ),
            'UpdateWorkitem': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWorkitem,
                    request_deserializer=workitems__pb2.UpdateWorkitemRequest.FromString,
                    response_serializer=workitems__pb2.UpdateWorkitemResponse.SerializeToString,
            ),
            'PopWorkitem': grpc.unary_unary_rpc_method_handler(
                    servicer.PopWorkitem,
                    request_deserializer=workitems__pb2.PopWorkitemRequest.FromString,
                    response_serializer=workitems__pb2.PopWorkitemResponse.SerializeToString,
            ),
            'DeleteWorkitem': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteWorkitem,
                    request_deserializer=workitems__pb2.DeleteWorkitemRequest.FromString,
                    response_serializer=workitems__pb2.DeleteWorkitemResponse.SerializeToString,
            ),
            'AddWorkItemQueue': grpc.unary_unary_rpc_method_handler(
                    servicer.AddWorkItemQueue,
                    request_deserializer=workitems__pb2.AddWorkItemQueueRequest.FromString,
                    response_serializer=workitems__pb2.AddWorkItemQueueResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'openiap.FlowService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FlowService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SetupStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/openiap.FlowService/SetupStream',
            base__pb2.Envelope.SerializeToString,
            base__pb2.Envelope.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Signin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/Signin',
            base__pb2.SigninRequest.SerializeToString,
            base__pb2.SigninResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Download(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/Download',
            base__pb2.DownloadRequest.SerializeToString,
            base__pb2.DownloadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Upload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/Upload',
            base__pb2.UploadRequest.SerializeToString,
            base__pb2.UploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CustomCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/CustomCommand',
            base__pb2.CustomCommandRequest.SerializeToString,
            base__pb2.CustomCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCollections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/ListCollections',
            querys__pb2.ListCollectionsRequest.SerializeToString,
            querys__pb2.ListCollectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DropCollection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/DropCollection',
            querys__pb2.DropCollectionRequest.SerializeToString,
            querys__pb2.DropCollectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Query(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/Query',
            querys__pb2.QueryRequest.SerializeToString,
            querys__pb2.QueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDocumentVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/GetDocumentVersion',
            querys__pb2.GetDocumentVersionRequest.SerializeToString,
            querys__pb2.GetDocumentVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Aggregate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/Aggregate',
            querys__pb2.AggregateRequest.SerializeToString,
            querys__pb2.AggregateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Count(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/Count',
            querys__pb2.CountRequest.SerializeToString,
            querys__pb2.CountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InsertOne(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/InsertOne',
            querys__pb2.InsertOneRequest.SerializeToString,
            querys__pb2.InsertOneResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InsertMany(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/InsertMany',
            querys__pb2.InsertManyRequest.SerializeToString,
            querys__pb2.InsertManyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOne(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/UpdateOne',
            querys__pb2.UpdateOneRequest.SerializeToString,
            querys__pb2.UpdateOneResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDocument(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/UpdateDocument',
            querys__pb2.UpdateDocumentRequest.SerializeToString,
            querys__pb2.UpdateDocumentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InsertOrUpdateOne(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/InsertOrUpdateOne',
            querys__pb2.InsertOrUpdateOneRequest.SerializeToString,
            querys__pb2.InsertOrUpdateOneResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InsertOrUpdateMany(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/InsertOrUpdateMany',
            querys__pb2.InsertOrUpdateManyRequest.SerializeToString,
            querys__pb2.InsertOrUpdateManyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOne(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/DeleteOne',
            querys__pb2.DeleteOneRequest.SerializeToString,
            querys__pb2.DeleteOneResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteMany(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/DeleteMany',
            querys__pb2.DeleteManyRequest.SerializeToString,
            querys__pb2.DeleteManyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterQueue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/RegisterQueue',
            queues__pb2.RegisterQueueRequest.SerializeToString,
            queues__pb2.RegisterQueueResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterExchange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/RegisterExchange',
            queues__pb2.RegisterExchangeRequest.SerializeToString,
            queues__pb2.RegisterExchangeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueueMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/QueueMessage',
            queues__pb2.QueueMessageRequest.SerializeToString,
            queues__pb2.QueueMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnRegisterQueue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/UnRegisterQueue',
            queues__pb2.UnRegisterQueueRequest.SerializeToString,
            queues__pb2.UnRegisterQueueResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Watch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/Watch',
            watch__pb2.WatchRequest.SerializeToString,
            watch__pb2.WatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnWatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/UnWatch',
            watch__pb2.UnWatchRequest.SerializeToString,
            watch__pb2.UnWatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PushWorkitem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/PushWorkitem',
            workitems__pb2.PushWorkitemRequest.SerializeToString,
            workitems__pb2.PushWorkitemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PushWorkitems(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/PushWorkitems',
            workitems__pb2.PushWorkitemsRequest.SerializeToString,
            workitems__pb2.PushWorkitemsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWorkitem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/UpdateWorkitem',
            workitems__pb2.UpdateWorkitemRequest.SerializeToString,
            workitems__pb2.UpdateWorkitemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PopWorkitem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/PopWorkitem',
            workitems__pb2.PopWorkitemRequest.SerializeToString,
            workitems__pb2.PopWorkitemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteWorkitem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/DeleteWorkitem',
            workitems__pb2.DeleteWorkitemRequest.SerializeToString,
            workitems__pb2.DeleteWorkitemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddWorkItemQueue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.FlowService/AddWorkItemQueue',
            workitems__pb2.AddWorkItemQueueRequest.SerializeToString,
            workitems__pb2.AddWorkItemQueueResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import os, sys, re
import json
import traceback
import asyncio
import logging
import zlib
import openiap
from google.protobuf import any_pb2
from openiap.client import GracefulKiller
from openiap.protowrap import protowrap 
from proto import base_pb2, queues_pb2
from google.protobuf import json_format

watchid = ""
async def onmessage(client, command, rid, message):
    reply = base_pb2.Envelope(command=command)
    reply.rid = rid
    try:
        if(command == "getelement"):
            logging.info(f"Server sent getelement {message.xpath}")
            reply.data.Pack(base_pb2.getelement(xpath=f"Did you say {message.xpath} ?"))
        elif(command == "queueevent"):
            data = json.loads(message.data);
        elif(command == "error"):
            reply.command = "noop"
            logging.error(f"SERVER ERROR !!! {str(message.message)} \n {str(message.stack)}")
        else:
            reply.command = "error"
            reply.data.Pack(base_pb2.error(message=f"Unknown command {command}"))
            logging.error(f"Got message with unknown command {command}")
    except Exception as e:
        print("runit EXCEPTION!!!!")
        print(repr(e))
        traceback.print_tb(e.__traceback__)
    return reply
async def findme333(client: openiap.Client, msg: base_pb2.Envelope, payload: dict):
    logging.info(f"findme333: {str(payload['name'])}")
async def findme222(client: openiap.Client, msg: base_pb2.Envelope, payload: dict):
    try:
        logging.info(f"findme222: {str(payload['name'])}")
    except:
        logging.info(f"findme222: {str(payload['payload']['name'])}")
        pass
async def pyqueue(client: openiap.Client, msg: base_pb2.Envelope, payload: dict):
    print("pyqueue triggered, PopWorkitem")
    # workitem = asyncio.run(self.c.PopWorkitem("pyqueue", True, True))
    workitem = await client.PopWorkitem("pyqueue", True, True)
    print("pyqueue PopWorkitem completed")
    workitem.state = "successful"
    workitem = await client.UpdateWorkitem(workitem)

    try:
        logging.info(f"findme222: {str(payload['name'])}")
    except:
        logging.info(f"findme222: {str(payload['payload']['name'])}")
        pass
async def getnoun(client: openiap.Client, msg: base_pb2.Envelope, payload: dict):
    text = "no-text"
    if("text" in payload):
        text = payload["text"]
    tmp = await client.GetElement("test")
    print(tmp)
    logging.info(f"getnoun: {str(msg.correlationId)} {str(text)}")
    payload["nouns"] = "yes, no"
    return payload

    # if(msg.replyto != "" and msg.replyto != None):
    #     reply = base_pb2.Envelope(command="queuemessage")
    #     res = json.dumps(payload)
    #     reply.data.Pack(queues_pb2.queuemessage(queuename=msg.replyto, data=res, striptoken=True, correlationId=msg.correlationId))
    #     client.queue.put(reply)
    # return payload
async def onconnected(client: openiap.Client):
    try:
        user = await client.Signin()
        logging.info(f"Signed in as {user.name}")
        q = await client.RegisterQueue("findme333", findme333)
        logging.info(f"Registered queue {q}")
        q = await client.RegisterQueue("findme222", findme222)
        logging.info(f"Registered queue {q}")
        q = await client.RegisterQueue("pyqueue", pyqueue)
        logging.info(f"Registered queue {q}")
        q = await client.RegisterQueue("getnoun", getnoun)
        logging.info(f"Registered queue {q}")
        
    except (Exception,BaseException) as e:
        print("onconnected!!!!")
        print(repr(e))
        traceback.print_tb(e.__traceback__)
        pass
async def entitieswatch(client: openiap.client, operation:str, document: dict):
    print(f"{operation} {document['_id']} {document['name']}")
async def main():
    loglevel = os.environ.get("loglevel", logging.INFO)
    if loglevel==logging.INFO:
        logging.basicConfig(format="%(message)s", level=loglevel)
    else:
        logging.basicConfig(format="%(levelname)s:%(message)s", level=loglevel)
    # c = client.Client("grpc://testuser:testuser@localhost:50051")
    apiurl = os.environ.get("apiurl", "")
    if(apiurl == ""):
        sys.exit(f"apiurl missing")
    c = openiap.Client(apiurl)
    c.onmessage = onmessage
    c.onconnected = onconnected

    while True:
        #try:
            # text = input("COMMAND: ")
            text = await c.ainput("COMMAND: ")
            text = re.sub(r'[^a-zA-Z0-9]', '', text)
            print(f"PROCESSING {text}")
            if text == "f":
                # filename = "/home/allan/Pictures/allan.png"
                id = "63d66fe01465b11939cd0d2d"
                name = "download.png";
                await c.DownloadFile(Id=id)
            elif text == "l":
                results = await c.ListCollections()
                if(results!=None):
                    for item in results:
                        print(item["name"])
            elif text == "g":
                result = await c.GetDocumentVersion("users", "6242d68a73057b27d277be88")
                if(result!=None):
                    print(result["name"])
            elif text == "c":
                result = await c.Count()
                print(result)
                result = await c.Count(collectionname="users")
                print(result)
            elif text == "a":
                results = await c.Aggregate("users", aggregates={"$match": {"_type": "user"}})
                if(results!=None):
                    for item in results:
                        print(item["name"])
            elif text == "i":
                result = await c.InsertOne(item={"name":"py find me"})
                print(f'{result["_id"]} {result["name"]}')
            elif text == "ii":
                results = await c.InsertMany(items=[{"name":"py find me 1"}, {"name":"py find me 2"}])
                if(results!=None):
                    for item in results:
                        print(f'{item["_id"]} {item["name"]}')
            elif text == "u":
                result = await c.InsertOne(item={"name":"py find me"})
                print(f'{result["_id"]} {result["name"]}')
                result["name"] = result["name"] + " Updated"
                result = await c.UpdateOne(item=result)
                print(f'{result["_id"]} {result["name"]}')
            elif text == "uu":
                result = await c.UpdateDocument({"_type":"unknown"},{"$set": {"name": "Updated"}} )
                print(f'acknowledged: {result.acknowledged} modified: {result.modifiedCount} matched: {result.matchedCount}')
            elif text == "iu":
                id = str(next(protowrap.uniqueid()))
                result = await c.InsertOrUpdateOne(item={"name":"InsertOrUpdateOne test " + id, "blah":"blah"}, uniqeness="blah")
                print(f'{result["_id"]} {result["name"]}')
            elif text == "ium":
                id = str(next(protowrap.uniqueid()))
                results = await c.InsertOrUpdateMany(items=[{"name":"InsertOrUpdateOne test 1 " + id, "blah":"blah1"}, {"name":"InsertOrUpdateOne test 2 " + id, "blah":"blah2"}], uniqeness="blah")
                if(results!=None):
                    for item in results:
                        print(f'{item["_id"]} {item["name"]}')
            elif text == "d":
                result = await c.InsertOne(item={"name":"py find me"})
                print(f'{result["_id"]} {result["name"]}')
                result["name"] = result["name"] + " Updated"
                result = await c.DeleteOne(result["_id"])
                print(f'Delete {result} items')
            elif text == "dd":
                result = await c.DeleteMany({"_type": "unknown"})
                print(f'Delete {result} items')
            elif text == "w":
                watchid = await c.Watch("entities", ["$.[?(@._type == 'test')]"], entitieswatch)
                print(f'watchid {watchid}')
            elif text == "uw":
                if(watchid!=""):
                    result = await c.UnWatch(id=watchid)
                    print(f'unwatch {watchid}')
                    watchid = ""
            elif text == "p":
                workitem = {"name": "Allan", "test":"Hi mom", "age":23, "files": []}
                filepath = "/home/allan/Pictures/allan.png"
                result = await c.PushWorkitem("q2", "find me", workitem, [filepath], compressed=True)
                logging.info(f"Workitem pushed with id {result._id}")

                workitem = await c.PopWorkitem("q2", True, True)
                if(workitem == None):
                    logging.info("No more workitems in queue q2")                    
                else:
                    try:
                        for f in workitem.files:
                            if f.compressed:
                                with open("download.png", "wb") as out_file:
                                    out_file.write(zlib.decompress(f.file))
                            else:
                                with open("download.png", "wb") as out_file:
                                    out_file.write(f.file)
                        logging.info(f"Popped workitem id {workitem._id}")
                        workitem.state = "successful"
                        payload = json.loads(workitem.payload)
                        logging.info(f"payload name {payload.get('name','unnamed')} workitem name {workitem.name}")
                        payload["name"] = "Allan 2222"
                        workitem.payload = json.dumps(payload)
                        workitem = await c.UpdateWorkitem(workitem, ["download.png"], True)
                        logging.info(f"Popped workitem id {workitem._id} now in state {workitem.state}")
                    except (Exception,BaseException) as e:
                         workitem.state = "retry"
                         workitem.errortype = "business" # business / application
                         workitem.errormessage = "".join(traceback.format_exception_only(type(e), e)).strip()
                         workitem.errorsource = "".join(traceback.format_exception(e))
                         await c.UpdateWorkitem(workitem)
                         print("Workitem EXCEPTION!!!!")
                         print(repr(e))
                         traceback.print_tb(e.__traceback__)
                         pass
            elif text == "s":
                signin = await c.Signin()
                logging.info(f"Signed in as {signin.name}")
            elif text == "q":
                # await c.QueueMessage("findme222", {"name":"py find me"})
                result = await c.QueueMessage("getnoun", {"name":"py find me"}, rpc=True)
                if(result!=None):
                    print(result["name"])
            elif text == "qq":
                # results = await c.Query(query={}, orderby={"name":-1})
                # results = await c.Query(query={}, orderby={"name":1})
                results = await c.Query()
                if(results!=None):
                    for item in results:
                        print(item["name"])
            elif text == "pp":
                filepath = "/home/allan/Pictures/allan.png"
                for i in range(1, 5):
                    workitem = {"name": f"item {i}", "test":"Hi mom", "age":23}
                    result = await c.PushWorkitem("pyagent", f"item {i}", workitem, [filepath], compressed=True)
                    logging.info(f"Workitem pushed item {i} with id {result._id}")
                    result = await c.PushWorkitem("nodeagent", f"item {i}", workitem, [filepath], compressed=True)
                    logging.info(f"Workitem pushed item {i} with id {result._id}")
            elif text == "push":
                workitem = {"test":"Hi mom", "age":23}
                result = await c.PushWorkitem("q2", "find me", workitem)
                logging.info(f"Workitem pushed with id {result._id}")
            else:
                xpath = await c.GetElement(text)
                logging.info(xpath)
        # except (Exception,BaseException) as e:
        #     print("MAIN EXCEPTION!!!!")
        #     print(repr(e))
        #     traceback.print_tb(e.__traceback__)
        #     pass
if __name__ == "__main__":
    killer = GracefulKiller()
    asyncio.run(main())



import asyncio, random, logging, threading, time, functools, traceback, grpc, json
from urllib.parse import urlparse
from proto import base_pb2, queues_pb2, workitems_pb2, querys_pb2, watch_pb2
from proto.base_pb2_grpc import FlowServiceStub
class protowrap():
    pending:dict = {}
    streams:dict = {}
    @staticmethod
    def Connect(client):
        uri = urlparse(client.url)
        if(uri.scheme == "grpc"):
            threading.Thread(target=protowrap.__grpc_listen_for_messages, args=(client, ), daemon=True).start()

    def __grpc_connect_and_listen(client, itr):
        try:
            uri = urlparse(client.url)
            if(uri.port == 443 or uri.port == "443"):
                logging.info(f"Connecting to {uri.hostname}:{uri.port} using ssl credentials")
                credentials = grpc.ssl_channel_credentials()
                client.chan = grpc.secure_channel(f"{uri.hostname}:{uri.port}", credentials, options=(('grpc.ssl_target_name_override', uri.hostname),))
            else:
                logging.info(f"Connecting to {uri.hostname}:{uri.port}")
                client.chan = grpc.insecure_channel(f"{uri.hostname}:{uri.port}")
            fut = grpc.channel_ready_future(client.chan)
            while not fut.done():
                logging.debug("channel is not ready")
                time.sleep(1)
            client.connected = True
            logging.info(f"Connected to {uri.hostname}:{uri.port}")
            asyncio.run_coroutine_threadsafe(client.onconnected(client), client.loop)
            logging.debug(f"Create stub and connect streams")
            stub = FlowServiceStub(client.chan)
            for message in stub.SetupStream(itr):
                logging.debug(f"RCV[{message.id}][{message.rid}][{message.command}]")
                protowrap.parse_message(client, message)
        except Exception as e:
            if(client.connected == True):
                client.connected = False
                print(repr(e))
                traceback.print_tb(e.__traceback__)
            pass
        logging.debug(f"Close channels")
        client.messagequeues = {}
        client.watches = {}
        for id in protowrap.pending:
            err = ValueError("Channel closed")
            client.loop.call_soon_threadsafe(protowrap.pending[id].set_exception, err)
        for id in protowrap.pending:
            err = ValueError("Channel closed")
            client.loop.call_soon_threadsafe(protowrap.pending[id].set_exception, err)
        client.chan.close()
    def __grpc_request_iterator(client, connectonid:str):
        try:
            logging.debug(f"Waiting for message for connecton id {connectonid}")
            message = client.grpcqueue.get()
            if(connectonid != protowrap.connectonid):
                client.grpcqueue.put(message)
                return None
            logging.debug(f"Process sending message for connecton id {connectonid}")
            if(message.id == None or message.id == ""): message.id = str(next(protowrap.uniqueid()))
            logging.debug(f"SND[{message.id}][{message.rid}][{message.command}]")
            return(message)
        except Exception as e:
            print(repr(e))
            traceback.print_tb(e.__traceback__)
            client.chan.close()
            pass        
    @staticmethod
    def __grpc_listen_for_messages(client):
        while True:
            protowrap.connectonid = str(next(protowrap.uniqueid()))
            count = 0
            logging.debug(f"Estabilish connecton id {protowrap.connectonid}")
            protowrap.__grpc_connect_and_listen(client,
                iter(functools.partial(protowrap.__grpc_request_iterator, client, protowrap.connectonid), None)
            )
            protowrap.connected = False
            count += 1
            logging.debug(f"Reconnect number {count}")
            time.sleep(2)
    @staticmethod
    def RPC(client, request:base_pb2.Envelope, id:str = ""):
        if(id == ""):
            id = str(next(protowrap.uniqueid()))
        request.id = id
        future = asyncio.Future()
        protowrap.pending[id] = future
        protowrap.sendMesssag(client, request, id)
        return future
    @staticmethod
    def sendMesssag(client, request:base_pb2.Envelope, id:str):
        if(request.id == None or request.id == ""):
            id = str(next(protowrap.uniqueid()))
            request.id = id
        if(client.grpcqueue != None):
            client.grpcqueue.put(request)
    @staticmethod
    def SetStream(rid:str):
        protowrap.streams[rid] = bytearray(0)
    @staticmethod
    def uniqueid():
        protowrap.seed = random.getrandbits(32)
        while True:
            yield protowrap.seed
            protowrap.seed += 1
    @staticmethod
    async def DownloadFile(client, Id:str=None, Filename:str=None):
        request = base_pb2.Envelope(command="download")
        request.data.Pack(base_pb2.DownloadRequest(filename=Filename,id=Id))
        rid = str(next(protowrap.uniqueid()))
        request.id = rid
        protowrap.SetStream(rid)
        result:base_pb2.DownloadResponse = await protowrap.RPC(client, request, rid)
        if(result.filename != None and result.filename != ""):
            with open(result.filename, "wb") as out_file:
                out_file.write(protowrap.streams[rid])
        protowrap.streams.pop(rid, None)
        return result
    async def __handle_onmessage_callback(client, message, msg):
        reply = await client.onmessage(client, message.command, message.id, msg)
        if(reply != None and message.rid == ""):
            if(reply.command != "noop"):
                protowrap.sendMesssag(client, reply, reply.id)

    async def __handle_watchevent_callback(client, msg):
        doc = json.loads(msg.document)
        await client.watches[msg.id](client, msg.operation, doc)
    async def __handle_queueevent_callback(client, msg):
        payload = json.loads(msg.data)
        if("payload" in payload):
            payload = payload["payload"]
        payload = await client.messagequeues[msg.queuename](client, msg, payload)
        if(payload != None  and msg.replyto != None and msg.replyto != ""):
            reply = base_pb2.Envelope(command="queuemessage")
            res = json.dumps(payload)
            reply.data.Pack(queues_pb2.QueueMessageRequest(queuename=msg.replyto, data=res, striptoken=True, correlationId=msg.correlationId))
            protowrap.sendMesssag(client, reply, reply.id)
    def parse_message(client, message:base_pb2.Envelope):
        return protowrap.__parse_message(client, message=message)
    def __parse_message(client, message:base_pb2.Envelope):
        msg = protowrap.__Unpack(message)
        if(message.command == "queueevent" and msg.correlationId in protowrap.pending and msg.replyto == ""):
            client.loop.call_soon_threadsafe(protowrap.pending[msg.correlationId].set_result, msg)
            protowrap.pending.pop(msg.correlationId, None)
        elif(message.rid in protowrap.streams and message.command in ["beginstream", "stream", "endstream"]):
            # if(message.command == "beginstream"):
            # elif(message.command == "endstream"):
            if(message.command == "stream"):
                # protowrap[message.rid] += msg.data
                protowrap.streams[message.rid].extend(msg.data)
        elif(message.rid in protowrap.pending):
            if(message.command == "error"):
                #raise ValueError(msg.message)
                client.loop.call_soon_threadsafe(protowrap.pending[message.rid].set_exception, ValueError(f"SERVER ERROR {msg.message}\n{msg.stack}" ))
            else:
                client.loop.call_soon_threadsafe(protowrap.pending[message.rid].set_result, msg)
            protowrap.pending.pop(message.rid, None)
        else:
            if(message.command == "watchevent" and msg.id in client.watches):
                asyncio.run_coroutine_threadsafe(protowrap.__handle_watchevent_callback(client, msg), client.loop)
            elif(message.command == "queueevent" and msg.queuename in client.messagequeues):
                asyncio.run_coroutine_threadsafe(protowrap.__handle_queueevent_callback(client, msg), client.loop)
            elif(message.command == "ping" or message.command == "pong" or message.command == "queuemessagereply"):
                pass
                #time.sleep(1)
            else:
                asyncio.run_coroutine_threadsafe(protowrap.__handle_onmessage_callback(client, message, msg), client.loop)
    def __Unpack(message:base_pb2.Envelope):
        if(message.command == "getelement"):
            msg = base_pb2.GetElementResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "signinreply"):
            msg = base_pb2.SigninResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "registerqueuereply"):
            msg = queues_pb2.RegisterQueueResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "queuemessagereply"):
            msg = queues_pb2.QueueMessageResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "queueevent"):
            msg = queues_pb2.QueueEvent()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "pushworkitemreply"):
            msg = workitems_pb2.PushWorkitemResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "popworkitemreply"):
            msg = workitems_pb2.PopWorkitemResponse()
            if(message.data.value != None and message.data.value != "" and message.data.value != b""):
                msg.ParseFromString(message.data.value);
                return msg
            else:
                return None
        elif(message.command == "updateworkitemreply"):
            msg = workitems_pb2.UpdateWorkitemResponse()
            if(message.data.value != None and message.data.value != "" and message.data.value != b""):
                msg.ParseFromString(message.data.value);
                return msg
            else:
                return None
        elif(message.command == "pong"):
            msg = base_pb2.PingResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "ping"):
            msg = base_pb2.PingRequest()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "error"):
            msg = base_pb2.ErrorResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "download"):
            msg = base_pb2.DownloadRequest()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "downloadreply"):
            msg = base_pb2.DownloadResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "stream"):
            msg = base_pb2.Stream()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "beginstream"):
            msg = base_pb2.BeginStream()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "endstream"):
            msg = base_pb2.EndStream()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "queryreply"):
            msg = querys_pb2.QueryResponse()
            msg.ParseFromString(message.data.value);
            return msg 
        elif(message.command == "listcollectionsreply"):
            msg = querys_pb2.ListCollectionsResponse()
            msg.ParseFromString(message.data.value);
            return msg 
        elif(message.command == "dropcollectionreply"):
            msg = querys_pb2.DropCollectionResponse()
            msg.ParseFromString(message.data.value);
            return msg 
        elif(message.command == "getdocumentversionreply"):
            msg = querys_pb2.GetDocumentVersionResponse()
            msg.ParseFromString(message.data.value);
            return msg 
        elif(message.command == "countreply"):
            msg = querys_pb2.CountResponse()
            msg.ParseFromString(message.data.value);
            return msg 
        elif(message.command == "aggregatereply"):
            msg = querys_pb2.AggregateResponse()
            msg.ParseFromString(message.data.value);
            return msg 
        elif(message.command == "insertonereply"):
            msg = querys_pb2.InsertOneResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "insertmanyreply"):
            msg = querys_pb2.InsertManyResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "updateonereply"):
            msg = querys_pb2.UpdateOneResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "updatedocumentreply"):
            msg = querys_pb2.UpdateDocumentResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "insertorupdateonereply"):
            msg = querys_pb2.InsertOrUpdateOneResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "insertorupdatemanyreply"):
            msg = querys_pb2.InsertOrUpdateManyResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "deleteonereply"):
            msg = querys_pb2.DeleteOneResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "deletemanyreply"):
            msg = querys_pb2.DeleteManyResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "watchreply"):
            msg = watch_pb2.WatchResponse()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "watchevent"):
            msg = watch_pb2.WatchEvent()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "unwatchreply"):
            msg = watch_pb2.UnWatchResponse()
            msg.ParseFromString(message.data.value);
            return msg
        else:
            logging.error(f"Got unknown {message.command} message")
            return None


from urllib.parse import urlparse
from queue import Queue
import gzip
import os
import json
import sys
from datetime import datetime
import asyncio
import time
import logging
import threading
import signal
from .protowrap import protowrap

from proto import base_pb2, queues_pb2, workitems_pb2, querys_pb2, watch_pb2


class Client():
    async def ainput(self, string: str) -> str:
        await asyncio.get_event_loop().run_in_executor(
                None, lambda s=string: sys.stdout.write(s+' '))
        return await asyncio.get_event_loop().run_in_executor(
                None, sys.stdin.readline)
    def __init__(self, url:str = ""):
        self.url = url
        self.replyqueue = ""
        if(self.url == None or self.url == ""): 
            self.url = os.environ.get("apiurl", "")
            self.jwt = os.environ.get("jwt", "")
            if(self.jwt == ""):
                uri = urlparse(self.url)
                if(uri.username == None or uri.username == "" or uri.password == None or uri.password == ""):
                    raise ValueError("No jwt environment variable and no credentials in url")
        if(self.url == None or self.url == ""): self.url = "grpc://grpc.app.openiap.io:443"
        self.connected = False
        self.loop = asyncio.get_event_loop()
        self.messagequeues = {}
        self.watches = {}
        self.grpcqueue = Queue()
        protowrap.Connect(self)
        # threading.Thread(target=self.__listen_for_messages, daemon=True).start()
        threading.Thread(target=self.__server_pinger, daemon=True).start()
    def Close(self):
        if(self.connected == True):
            self.connected = False
            self.chan.close()
    async def onmessage(self, client, command, rid, message):
        logging.info(f"Got {command} message event")
    async def onconnected(self, client):
        logging.info(f"Connected")
        # uri = urlparse(self.url)
        # if(uri.username != None and uri.username != "" and uri.password != None and uri.password != ""):
        #     await self.Signin(uri.username, uri.password)
    def __server_pinger(self):
        count = 0
        while True:
            time.sleep(5)
            if(self.connected):
                message = base_pb2.Envelope(command="ping")
                self.grpcqueue.put(message)
            time.sleep(25)
            count += 1
    async def Signin(self, username:str=None, password:str=None, ping:bool=True):
        request = base_pb2.Envelope(command="signin")
        if(username == None and password==None):
            jwt = os.environ.get("jwt", "")
            if jwt != "":
                username=jwt
            else:
                uri = urlparse(self.url)
                if(uri.username != None and uri.username != "" and uri.password != None and uri.password != ""):
                    username=uri.username
                    password=uri.password
        if(password== None or password == ""):
            request.data.Pack(base_pb2.SigninRequest(jwt=username, ping=ping, agent="pyclient"))
        else:
            request.data.Pack(base_pb2.SigninRequest(username=username, password=password, ping=ping, agent="pyclient"))
        result:base_pb2.SigninResponse = await protowrap.RPC(self, request)
        self.jwt = result.jwt
        self.user = result.user
        return result.user
    async def DownloadFile(self, Id:str=None, Filename:str=None):
        result = await protowrap.DownloadFile(self, Id, Filename)
        return result
    async def GetElement(self, xpath:str):
        request = base_pb2.Envelope(command="getelement")
        request.data.Pack(base_pb2.GetElementRequest(xpath=xpath))
        result:base_pb2.GetElementResponse = await protowrap.RPC(self, request)
        return result.xpath
    async def RegisterQueue(self, queuename:str, callback):
        request = base_pb2.Envelope(command="registerqueue")
        request.data.Pack(queues_pb2.RegisterQueueRequest(queuename=queuename))
        result:queues_pb2.RegisterQueueResponse = await protowrap.RPC(self, request)
        self.messagequeues[result.queuename] = callback
        if(self.replyqueue == ""):
            self.replyqueue = result.queuename
        return result.queuename
    async def QueueMessage(self, queuename:str, payload, correlationId=None, striptoken=True, rpc=False):
        future = None
        replyto = ""
        if(rpc==True and self.replyqueue != ""):
            correlationId = str(next(protowrap.uniqueid()))
            future = asyncio.Future()
            protowrap.pending[correlationId] = future
            replyto = self.replyqueue

        reply = base_pb2.Envelope(command="queuemessage")
        res = json.dumps(payload)
        reply.data.Pack(queues_pb2.QueueMessageRequest(queuename=queuename, data=res, striptoken=striptoken, correlationId=correlationId, replyto=replyto))
        self.grpcqueue.put(reply)
        if(future!=None):
            msg:queues_pb2.QueueMessageResponse = await future
            payload = json.loads(msg.data)
            if("payload" in payload):
                payload = payload["payload"]
            return payload
    async def PushWorkitem(self, wiq:str, name:str, payload:dict, files: any = None, wiqid:str = None, nextrun: datetime = None, priority: int = 2, compressed: bool = False):
        request = base_pb2.Envelope(command="pushworkitem")
        _files = []
        if(files != None):
            for filepath in files:
                filename = os.path.basename(filepath)
                if compressed == True:
                    with open(filepath, mode="rb") as content:
                        _files.append({"filename":filename, "compressed": compressed, "file": gzip.compress(content.read())})
                else:
                    with open(filepath, mode="rb") as content:
                        _files.append({"filename":filename, "compressed": compressed, "file": content.read()})
        q = workitems_pb2.PushWorkitemRequest(wiq=wiq,name=name, files=_files, wiqid=wiqid, nextrun=nextrun, priority=priority )
        q.payload = json.dumps(payload)
        request.data.Pack(q)
        result:workitems_pb2.PushWorkitemResponse = await protowrap.RPC(self, request)
        return result.workitem;
    async def PopWorkitem(self, wiq:str,includefiles:bool=False,compressed:bool=False):
        request = base_pb2.Envelope(command="popworkitem")
        request.data.Pack(workitems_pb2.PopWorkitemRequest(wiq=wiq,includefiles=includefiles,compressed=compressed))
        result:workitems_pb2.PopWorkitemResponse = await protowrap.RPC(self, request)
        if(result == None): return None
        return result.workitem;
    async def UpdateWorkitem(self, workitem, files: any = None, compressed:bool=False):
        request = base_pb2.Envelope(command="updateworkitem")
        _files = []
        for f in workitem.files:
            workitem.files.remove(f)
        if(files != None):
            for filepath in files:
                filename = os.path.basename(filepath)
                if compressed == True:
                    with open(filepath, mode="rb") as content:
                        _files.append({"filename":filename, "compressed": compressed, "file": gzip.compress(content.read())})
                else:
                    with open(filepath, mode="rb") as content:
                        _files.append({"filename":filename, "compressed": compressed, "file": content.read()})
        uwi = workitems_pb2.UpdateWorkitemRequest(workitem = workitem, files = _files);
        request.data.Pack(uwi)
        result:workitems_pb2.UpdateWorkitemResponse = await protowrap.RPC(self, request)
        if(result == None): return None
        return result.workitem;
    async def Query(self, collectionname:str="entities", query:dict={}, projection:dict={},top:int=100,skip:int=0, orderby=None, queryas:str=None):
        o = orderby
        if(not isinstance(o, str)): o = json.dumps(o)
        request = base_pb2.Envelope(command="query")
        request.data.Pack(querys_pb2.QueryRequest(
            collectionname=collectionname, query=json.dumps(query), projection=json.dumps(projection), top=top,skip=skip, orderby=o, queryas=queryas))
        result:querys_pb2.QueryResponse = await protowrap.RPC(self, request)
        if(result == None or result.results == None): return None
        return json.loads(result.results)
    async def ListCollections(self, includehist:bool=False):
        request = base_pb2.Envelope(command="listcollections")
        request.data.Pack(querys_pb2.ListCollectionsRequest(includehist=includehist))
        result:querys_pb2.ListCollectionsResponse = await protowrap.RPC(self, request)
        if(result == None or result.results == None): return None
        return json.loads(result.results)
    async def DropCollection(self, collectionname:str):
        request = base_pb2.Envelope(command="dropcollection")
        request.data.Pack(querys_pb2.DropCollectionRequest(collectionname=collectionname))
        await protowrap.RPC(self, request)
    async def GetDocumentVersion(self, id:str, collectionname:str, version:int = 0, decrypt:bool=True):
        request = base_pb2.Envelope(command="getdocumentversion")
        request.data.Pack(querys_pb2.GetDocumentVersionRequest(collectionname=collectionname, id=id, version=version, decrypt=decrypt))
        result:querys_pb2.GetDocumentVersionResponse = await protowrap.RPC(self, request)
        if(result == None or result.result == None or result.result == ""): return None
        return json.loads(result.result)
    async def Count(self, query:dict={}, collectionname:str="entities", queryas:str=None):
        request = base_pb2.Envelope(command="count")
        request.data.Pack(querys_pb2.CountRequest(
            collectionname=collectionname, query=json.dumps(query), queryas=queryas))
        result:querys_pb2.CountResponse = await protowrap.RPC(self, request)
        if(result == None): return 0
        return result.result
    async def Aggregate(self, aggregates:dict={}, collectionname:str="entities", queryas:str=None):
        request = base_pb2.Envelope(command="aggregate")
        request.data.Pack(querys_pb2.AggregateRequest(
            collectionname=collectionname, aggregates=json.dumps(aggregates), queryas=queryas))
        result:querys_pb2.AggregateResponse = await protowrap.RPC(self, request)
        if(result == None or result.results == None): return None
        return json.loads(result.results)
    async def InsertOne(self, item:dict, collectionname:str="entities"):
        request = base_pb2.Envelope(command="insertone")
        request.data.Pack(querys_pb2.InsertOneRequest(
            collectionname=collectionname, item=json.dumps(item)))
        result:querys_pb2.InsertOneResponse = await protowrap.RPC(self, request)
        if(result == None or result.result == None): return None
        return json.loads(result.result)
    async def InsertMany(self, items:list(), collectionname:str="entities", skipresults:bool=False):
        request = base_pb2.Envelope(command="insertmany")
        request.data.Pack(querys_pb2.InsertManyRequest(
            collectionname=collectionname, items=json.dumps(items), skipresults=skipresults))
        result:querys_pb2.InsertManyResponse = await protowrap.RPC(self, request)
        if(result == None or result.results == None): return None
        return json.loads(result.results)
    async def UpdateOne(self, item:dict, collectionname:str="entities"):
        request = base_pb2.Envelope(command="updateone")
        request.data.Pack(querys_pb2.UpdateOneRequest(
            collectionname=collectionname, item=json.dumps(item)))
        result:querys_pb2.UpdateOneResponse = await protowrap.RPC(self, request)
        if(result == None or result.result == None): return None
        return json.loads(result.result)
    async def UpdateDocument(self, query:dict, document:dict, collectionname:str="entities"):
        request = base_pb2.Envelope(command="updatedocument")
        request.data.Pack(querys_pb2.UpdateDocumentRequest(
            collectionname=collectionname, query=json.dumps(query), document=json.dumps(document)))
        result:querys_pb2.UpdateDocumentResponse = await protowrap.RPC(self, request)
        if(result == None or result.opresult == None): return None
        return result.opresult
    async def InsertOrUpdateOne(self, item:dict, collectionname:str="entities", uniqeness:str="_id"):
        request = base_pb2.Envelope(command="insertorupdateone")
        request.data.Pack(querys_pb2.InsertOrUpdateOneRequest(
            collectionname=collectionname, uniqeness=uniqeness, item=json.dumps(item)))
        result:querys_pb2.InsertOrUpdateOneResponse = await protowrap.RPC(self, request)
        if(result == None or result.result == None): return None
        return json.loads(result.result)
    async def InsertOrUpdateMany(self, items:dict, collectionname:str="entities", uniqeness:str="_id", skipresults:bool=False):
        request = base_pb2.Envelope(command="insertorupdatemany")
        request.data.Pack(querys_pb2.InsertOrUpdateManyRequest(
            collectionname=collectionname, uniqeness=uniqeness, items=json.dumps(items), skipresults=skipresults))
        result:querys_pb2.InsertOrUpdateManyResponse = await protowrap.RPC(self, request)
        if(result == None or result.results == None): return None
        return json.loads(result.results)
    async def DeleteOne(self, id:str, collectionname:str="entities", recursive:bool=False):
        request = base_pb2.Envelope(command="deleteone")
        request.data.Pack(querys_pb2.DeleteOneRequest(
            collectionname=collectionname, id=id, recursive=recursive))
        result:querys_pb2.DeleteOneResponse = await protowrap.RPC(self, request)
        if(result == None): return 0
        return result.affectedrows
    async def DeleteMany(self, query:dict, collectionname:str="entities", recursive:bool=False):
        request = base_pb2.Envelope(command="deletemany")
        request.data.Pack(querys_pb2.DeleteManyRequest(
            collectionname=collectionname, query=json.dumps(query), recursive=recursive))
        result:querys_pb2.DeleteManyResponse = await protowrap.RPC(self, request)
        if(result == None): return 0
        return result.affectedrows
    async def Watch(self, collectionname, paths:list, callback):
        request = base_pb2.Envelope(command="watch")
        request.data.Pack(watch_pb2.WatchRequest (collectionname=collectionname, paths=paths))
        result:watch_pb2.WatchResponse = await protowrap.RPC(self, request)
        self.watches[result.id] = callback
        return result.id
    async def UnWatch(self, id:str):
        request = base_pb2.Envelope(command="unwatch")
        request.data.Pack(watch_pb2.UnWatchRequest (id=id))
        result:watch_pb2.UnWatchResponse = await protowrap.RPC(self, request)
        self.watches.pop(id, None)
class GracefulKiller:
  kill_now = False
  def __init__(self):
    signal.signal(signal.SIGINT, self.exit_gracefully)
    signal.signal(signal.SIGTERM, self.exit_gracefully)

  def exit_gracefully(self, *args):
    self.kill_now = True
    sys.exit()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: watch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bwatch.proto\x12\x07openiap\"5\n\x0cWatchRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05paths\x18\x02 \x03(\t\"\x1b\n\rWatchResponse\x12\n\n\x02id\x18\x01 \x01(\t\"=\n\nWatchEvent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\toperation\x18\x02 \x01(\t\x12\x10\n\x08\x64ocument\x18\x03 \x01(\t\"\x1c\n\x0eUnWatchRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x11\n\x0fUnWatchResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'watch_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WATCHREQUEST._serialized_start=24
  _WATCHREQUEST._serialized_end=77
  _WATCHRESPONSE._serialized_start=79
  _WATCHRESPONSE._serialized_end=106
  _WATCHEVENT._serialized_start=108
  _WATCHEVENT._serialized_end=169
  _UNWATCHREQUEST._serialized_start=171
  _UNWATCHREQUEST._serialized_end=199
  _UNWATCHRESPONSE._serialized_start=201
  _UNWATCHRESPONSE._serialized_end=218
# @@protoc_insertion_point(module_scope)
